@@ -9,7 +9,7 @@ mod tests {
         for i in 0..20 {
             println!("{} is a prime number: {}", i, check_prime(i));
         }
-        println!("Prime numbers from 1'000'000 to 1'000'100: {:?}", check_area(1, 20));
+        println!("Prime numbers from 1 to 20: {:?}", check_area(1, 20));
         println!("It works!");
     }
 }
